@@ -168,7 +168,7 @@ def generate_fixes_query(f):
         
     return query
 
-def fixes_filter_logic(filters, limit=None, hide_hosts=False):
+def fixes_filter_logic(filters, limit=None):
     db = init_db()
     if filters['skipped'] == "False" or filters['skipped'] == "false":
         filters['skipped'] = False
@@ -176,7 +176,7 @@ def fixes_filter_logic(filters, limit=None, hide_hosts=False):
         filters['skipped'] = True
     query = generate_fixes_query(filters)
     limit = limit if limit else int(filters['pageLength'])
-    return db.getFixes(limit=limit, skip=int(filters['r']), query=query, hide_hosts=hide_hosts)
+    return db.getFixes(limit=limit, skip=int(filters['r']), query=query)
 
 
 ##########
@@ -188,14 +188,14 @@ def fixes_filter_logic(filters, limit=None, hide_hosts=False):
 def api_vulns():
     db = init_db()
     vulns = db.getVulns()
-    if not vulns: raise(APIError('vulns not found', 404))
+    #~ if not vulns: raise(APIError('vulns not found', 404))
     return vulns  
   
 @api
 def api_vulns_post():
     filters = getFilterSettingsFromPost()
     vulns = vulns_filter_logic(filters)
-    if not vulns: raise(APIError('vulns not found', 404))
+    #~ if not vulns: raise(APIError('vulns not found', 404))
     return vulns
 
 # /api/vuln/<vulnid>
@@ -205,6 +205,14 @@ def api_vuln(vulnid):
     vuln = db.getVulns(query={'id': vulnid})
     if not vuln: raise(APIError('vuln not found', 404))
     return vuln
+    
+# /api/vulns/stats
+@api
+def api_vulns_stats():
+    db = init_db()
+    vulns_stats = db.getVulnsStats()
+    if not vulns_stats: raise(APIError('vulns stats not found', 404))
+    return vulns_stats
 
 # /api/pkgs
 @api
@@ -255,14 +263,14 @@ def api_pkgsearch(pkgvers):
 def api_hosts():
     db = init_db()
     hosts = db.getHosts()
-    if not hosts: raise(APIError('hosts not found', 404))
+    #~ if not hosts: raise(APIError('hosts not found', 404))
     return hosts
     
 @api
 def api_hosts_post():
     filters = getFilterSettingsFromPost()
     hosts = hosts_filter_logic(filters)
-    if not hosts: raise(APIError('hosts not found', 404))
+    #~ if not hosts: raise(APIError('hosts not found', 404))
     return hosts
     
 # /api/hosts/stats
@@ -302,7 +310,7 @@ def api_host_pkgs(hostname):
 def api_host_vulns(hostname):
     db = init_db()
     host_vulns = db.getHostVulns(hostname)
-    if not host_vulns: raise(APIError('host s vulns not found', 404))
+    #~ if not host_vulns: raise(APIError('host s vulns not found', 404))
     return host_vulns
 
 # /api/host/fixes/<hostname>
@@ -310,7 +318,7 @@ def api_host_vulns(hostname):
 def api_host_fixes(hostname):
     db = init_db()
     host_fixes = db.getFixes(query={'hosts': hostname}, hide_hosts=True)
-    if not host_fixes: raise(APIError('host s fixes not found', 404))
+    #~ if not host_fixes: raise(APIError('host s fixes not found', 404))
     return host_fixes
     
 # /api/fixes
@@ -318,26 +326,16 @@ def api_host_fixes(hostname):
 def api_fixes():
     db = init_db()
     fixes = db.getFixes()
-    if not fixes: raise(APIError('fixes not found', 404))
+    #~ if not fixes: raise(APIError('fixes not found', 404))
     return fixes
 
 @api
 def api_fixes_post():
     filters = getFilterSettingsFromPost()
-    hide_hosts = False
-    if filters['hostname'] != "all":
-        hide_hosts = True
-    fixes = fixes_filter_logic(filters, hide_hosts=hide_hosts)
-    if not fixes: raise(APIError('fixes not found', 404))
+    fixes = fixes_filter_logic(filters)
+    #~ if not fixes: raise(APIError('fixes not found', 404))
     return fixes
     
-# /api/vulns/stats
-@api
-def api_vulns_stats():
-    db = init_db()
-    vulns_stats = db.getVulnsStats()
-    if not vulns_stats: raise(APIError('vulns stats not found', 404))
-    return vulns_stats
     
 # /api/fixes/stats
 @api
