@@ -1,21 +1,3 @@
-# Functions to check which vulnerabilities exists in cve-search database for 
-# the products in database
-#
-# Imported in fixdb in the collection named vulns.
-#
-# The format of the collection is the following
-#
-# Made by Gaetan Egger
-#
-# Inspired from cve-search
-#
-# Software is free software released under the "Modified BSD license"
-#
-# Copyright (c) 2012         Wim Remes
-# Copyright (c) 2012-2014     Alexandre Dulaunoy - a@foo.be
-# Copyright (c) 2014-2016     Pieter-Jan Moreels - pieterjan.moreels@gmail.com
-
-# Imports
 import re, datetime, subprocess
 
 # To import debsecan conf
@@ -272,7 +254,10 @@ def debsecan_vulns(db):
 
     (url, backup_file_path) = conf.getDebsecanConf()
     
-    suites = db.getSuites()
+    suites = []
+    suites_json = db.getSuites()
+    for suite_json in suites_json:
+        suites.append(suite_json['suite'])
     
     logging.info('[%s] (%s)\tStarted check debsecan_vulns.', datetime.datetime.today().isoformat(), __name__)
     
@@ -307,8 +292,12 @@ def ubuntu_vulns(db):
     nb_mod = 0
     nb_err = 0
 
+    releases = []
+    releases_json = db.getReleases()
+    for release_json in releases_json:
+        releases.append(release_json['release'])
+    
     
-    releases = db.getReleases()
     for release in releases:
         tables = uctl.ubuntuTable(release)
         pkgs = db.getPackages(query={'os_type': "Ubuntu", 'os_version': release})
@@ -371,13 +360,13 @@ def debsecan_fixes(db):
         if len(pkg_vulns) > 0:
             pkg_list.append(pkg)
             pkg_vulns_index[pkg['id'] + ":" + pkg['version']] = pkg_vulns
-            
+        
     for pkg in pkgs:
         try:
             pkg_vulns = pkg_vulns_index[pkg['id'] + ":" + pkg['version']]
         except KeyError as ke:
             continue
-            
+        
         suite = pkg['os_version']
         
         for pkg_vuln in pkg_vulns:
@@ -391,26 +380,26 @@ def debsecan_fixes(db):
                 #~ # To only keep newer fixed version
                 for fixed_version in pkg_vuln['fixed_versions']:
                     # Check if debXuY correspong to current suite
-                    if bool(re.match(r'[\w\.\+\-\~]+deb' + f.suite2tag(suite) + r'u[\d]{1,2}', fixed_version)) == True:
+                    if (bool(re.match(r'[\w\.\+\-\~]+deb' + f.suite2tag(suite) + r'u[\d]{1,2}', fixed_version)) == True) or (bool(re.match(r'[\w\.\+\-\~]' + suite + r'[\d]{1,2}', fixed_version)) == True) or (suite == "wheezy" and bool(re.match(r'[\d\.\+\-\~]', fixed_version))):
                         if check_versions(pkg['version'], fixed_version, "fix") == True:
                             fixes.append(Vulns.Fix(pkg['hosts'], pkg['id'], pkg['version'], pkg['src_id'], pkg['src_version'], fixed_version, pkg_vuln['remotely_exp'], pkg_vuln['urgency'], cve_ids, pkg['os_type'], pkg['os_version'], pkg_vuln['src'], False, "", "").to_json())
                             # To make the check faster and indicate the first version fixed
                             break
             # Check backport (if bpoX correspond to current suite)
-            elif bool(re.match(r'[\w\.\+\-\~]+\~bpo' + f.suite2tag(suite) + r'\d?\+[\w\+\-\~]+', pkg['src_version'])) == True:
+            #elif bool(re.match(r'[\w\.\+\-\~]+\~bpo' + f.suite2tag(suite) + r'\d?\+[\w\+\-\~]+', pkg['src_version'])) == True:
                 
-                cve_ids = []
-                cve_ids.append(pkg_vuln['id'])
+            #    cve_ids = []
+            #    cve_ids.append(pkg_vuln['id'])
             
                 #~ # To only keep newer fixed version
-                for fixed_version in pkg_vuln['fixed_versions']:
+            #    for fixed_version in pkg_vuln['fixed_versions']:
                     #~ logging.info('[%s] (%s)\tBPO %s : %s\t%s.', datetime.datetime.today().isoformat(), __name__,pkg['id'], pkg['version'], fixed_version)
-                    if check_versions(pkg['version'], fixed_version, "fix") == True:
-                        fixes.append(Vulns.Fix(pkg['hosts'], pkg['id'], pkg['version'], pkg['src_id'], pkg['src_version'], fixed_version, pkg_vuln['remotely_exp'], pkg_vuln['urgency'], cve_ids, pkg['os_type'], pkg['os_version'], pkg_vuln['src'], False, "", "").to_json())
+            #        if check_versions(pkg['version'], fixed_version, "fix") == True:
+            #            fixes.append(Vulns.Fix(pkg['hosts'], pkg['id'], pkg['version'], pkg['src_id'], pkg['src_version'], fixed_version, pkg_vuln['remotely_exp'], pkg_vuln['urgency'], cve_ids, pkg['os_type'], pkg['os_version'], pkg_vuln['src'], False, "", "").to_json())
                         # To make the check faster and indicate the first version fixed
-                        break
+            #            break
                                 
-    # ~ logging.info('[%s] (%s)\t%d fixed_vuln read.', datetime.datetime.today().isoformat(), __name__, len(fixes))
+    logging.info('[%s] (%s)\t%d fixed_vuln read.', datetime.datetime.today().isoformat(), __name__, len(fixes))
     
     for fix in fixes:
         result = db.insertFix(fix)
@@ -503,8 +492,15 @@ def madison_fixes(db):
     fixes = []
     
     # ~ print(ubuntu_host['id'])
-    suites = db.getSuites()
-    releases = db.getReleases()
+    suites = []
+    suites_json = db.getSuites()
+    for suite_json in suites_json:
+        suites.append(suite_json['suite'])
+    
+    releases = []
+    releases_json = db.getReleases()
+    for release_json in releases_json:
+        releases.append(release_json['release'])
     
     for suite in suites:
         # ~ logging.info('[%s] (%s)\tRelease found: %s', datetime.datetime.today().isoformat(), __name__, release)
