@@ -115,13 +115,26 @@ class DatabaseLayer(object):
       return self.sanitize(pkg)
     
     def getOSVersions(self):
-        return self.hostdb["hosts"].distinct('os_version')
+        os_versions_json = []
+        os_versions = self.hostdb["hosts"].distinct('os_version')
+        for os_version in os_versions:
+            os_versions_json.append({'os_version' : os_version})
+        return os_versions_json
     
     def getSuites(self):
-        return self.hostdb["packages"].distinct('os_version', filter={'os_type': "Debian"})
+        suites_json = []
+        suites = self.hostdb["packages"].distinct('os_version', filter={'os_type': "Debian"})
+        for suite in suites:
+            suites_json.append({'suite' : suite})
+        return suites_json
         
     def getReleases(self):
-        return self.hostdb["packages"].distinct('os_version', filter={'os_type': "Ubuntu"})
+        releases_json = []
+        releases = self.hostdb["packages"].distinct('os_version', filter={'os_type': "Ubuntu"})
+        for release in releases:
+            releases_json.append({'release' : release})
+        return releases_json
+        
          
     def getHosts(self, limit=False, query=[], skip=0):
       if type(query) == dict: query=[query]
@@ -134,13 +147,20 @@ class DatabaseLayer(object):
       return self.sanitize(hosts)
       
     def getFixableHosts(self):
-        return self.fixdb["fixes"].distinct('hosts')
+        fixable_hosts_json = []
+        fixable_hosts = self.fixdb["fixes"].distinct('hosts')
+        for fixable_host in fixable_hosts:
+            fixable_hosts_json.append({'fixable_host' : fixable_host})
+        return fixable_hosts_json
         
     def getHostsStats(self):
         totvuln = self.vulndb["vulns"].count()
         totfix = self.fixdb["fixes"].count()
         
-        hostnames = self.getFixableHosts()
+        hostnames_json = self.getFixableHosts()
+        hostnames = []
+        for hostname_json in hostnames_json:
+            hostnames.append(hostname_json['fixable_host'])
         
         rules = json.load(open(conf.getRulesFile()))
         
