@@ -1,28 +1,28 @@
 function checkdsavulns() {
     alert("Check debsecan vulnerabilities command launched");
-    $.getJSON("/ivulncheck_api/cmd/check/debsecan_vulns");
+    $.getJSON("/ivulncheck/checks/debsecan_vulns");
 }
 function checkdsafixes() {
     alert("Check debsecan fixes command launched");
-    $.getJSON("/ivulncheck_api/cmd/check/debsecan_fixes");
+    $.getJSON("/ivulncheck/checks/debsecan_fixes");
 }
 function checkubvulns() {
     alert("Check ubuntu vulnerabilities command launched");
-    $.getJSON("/ivulncheck_api/cmd/check/ubuntu_vulns");
+    $.getJSON("/ivulncheck/checks/ubuntu_vulns");
 }
 function checkubfixes() {
     alert("Check ubuntu fixes command launched");
-    $.getJSON("/ivulncheck_api/cmd/check/ubuntu_fixes");
+    $.getJSON("/ivulncheck/checks/ubuntu_fixes");
 }
 function checkpdvulns() {
     alert("Check products vulnerabilities command launched");
-    $.getJSON("/ivulncheck_api/cmd/check/products_vulns");
+    $.getJSON("/ivulncheck/checks/products_vulns");
 }  
 function checkmsfixes() {
     alert("Check madison fixes command launched");
-    $.getJSON("/ivulncheck_api/cmd/check/madison_fixes");
+    $.getJSON("/ivulncheck/checks/madison_fixes");
 }
 function calcstats(hostname) {
     alert("Updating Stats for " + hostname);
-    $.getJSON("/ivulncheck_api/cmd/calcstats/" + hostname);
+    $.getJSON("/ivulncheck/calcstats/" + hostname);
 }
