@@ -1,17 +1,15 @@
 // Requires filter.js, where setSetings() is located
-function postURL(url, n) {
+function postURL(n) {
+  var url = $(location).attr('href');
   var form = document.getElementById("filter");
   form.r.value = n;
-  form.action = url;
   form.submit();
 }
 function next(n){
-  url =$(location).attr('href');
-  postURL(url, n);
+  postURL(n);
 }
 function previous(n){
-  url =$(location).attr('href');  
   if(n < 0){
     n = 0;}
-  postURL(url, n);
+  postURL(n);
 }
